ca_blur

ca_focus
open | /demo/ca_blur.html |
assertTextPresent | Blur away from none. |
fireEvent | input | blur
assertTextPresent | Blur away from input. |
fireEvent | remote-input | blur
assertTextPresent | Blur away from remote-input. |
fireEvent | textarea | blur
assertTextPresent | Blur away from textarea. |
fireEvent | remote-textarea | blur
assertTextPresent | Blur away from remote-textarea. |
fireEvent | select | blur
assertTextPresent | Blur away from select. |
fireEvent | remote-select | blur
assertTextPresent | Blur away from remote-select. |
fireEvent | radio | blur
assertTextPresent | Blur away from radio. |
fireEvent | remote-radio | blur
assertTextPresent | Blur away from remote-radio. |
fireEvent | checkbox | blur
assertTextPresent | Blur away from checkbox. |
fireEvent | remote-checkbox | blur
assertTextPresent | Blur away from remote-checkbox. |